# -*- coding: utf-8 -*-
#
# Copyright (C) 2022 TU Wien.
# Copyright (C) 2025 Northwestern University.
#
# Invenio-Users-Resources is free software; you can redistribute it and/or
# modify it under the terms of the MIT License; see LICENSE file for more
# details.

"""Definitions that are used by both users and user groups services."""

from invenio_records_resources.services import EndpointLink


class EndpointLinkWithId(EndpointLink):
    """Defines vars for endpoints whose routes use <id>."""

    def __init__(self, *args, **kwargs):
        """Constructor."""
        super().__init__(*args, **kwargs)
        self._params.append("id")

    @staticmethod
    def vars(obj, vars):
        """Update vars used to expand/fill the link."""
        vars.update({"id": obj.id})


def vars_func_set_querystring(func_qs=lambda obj, vars: {}):
    """Fill in querystring parameters easily."""

    def _inner(obj, vars):
        vars.setdefault("args", {})
        vars["args"].update(func_qs(obj, vars))

    return _inner



# -*- coding: utf-8 -*-
#
# Copyright (C) 2025 CERN.
# Copyright (C) 2025 KTH Royal Institute of Technology.
#
# Invenio-Users-Resources is free software; you can redistribute it and/or
# modify it under the terms of the MIT License; see LICENSE file for more
# details.

"""Groups resource errors."""

from invenio_i18n import lazy_gettext as _


class GroupsException(Exception):
    """Base exception for groups resource errors."""


class GroupValidationError(GroupsException):
    """Raised when a group payload fails validation."""

    message = _("A validation error occurred.")

    def __init__(self, errors):
        """Marshmallow validation errors."""
        self.errors = errors
        self.description = self.message
        super().__init__(self.message)



# -*- coding: utf-8 -*-
#
# Copyright (C) 2022 KTH Royal Institute of Technology
# Copyright (C) 2022 TU Wien.
# Copyright (C) 2022 CERN.
# Copyright (C) 2022 European Union.
# Copyright (C) 2025 KTH Royal Institute of Technology.
#
# Invenio-Users-Resources is free software; you can redistribute it and/or
# modify it under the terms of the MIT License; see LICENSE file for more
# details.

"""Groups service."""

from flask import current_app
from invenio_accounts.models import Role
from invenio_db import db
from invenio_records_resources.resources.errors import PermissionDeniedError
from invenio_records_resources.services import RecordService
from invenio_records_resources.services.uow import (
    RecordCommitOp,
    RecordIndexDeleteOp,
    unit_of_work,
)
from marshmallow import ValidationError

from ...records.api import GroupAggregate
from ...resources.groups.errors import GroupValidationError
from ..results import AvatarResult


class GroupsService(RecordService):
    """User groups service."""

    @unit_of_work()
    def create(self, identity, data, raise_errors=True, uow=None):
        """Create a new group/role."""
        self.require_permission(identity, "create", record=data)
        try:
            data, errors = self.schema.load(
                data or {},
                context={"identity": identity},
                raise_errors=raise_errors,
            )
        except ValidationError as err:
            raise GroupValidationError(err.messages)

        try:
            # Create group using API
            group = self.record_cls.create(data)
        except ValidationError as err:
            raise GroupValidationError(err.messages) from err

        current_app.logger.debug(
            "Group created: '%s' by user %s", group.name, identity.id
        )

        self.run_components(
            "create",
            identity,
            data=data,
            group=group,
            errors=errors,
            uow=uow,
        )

        uow.register(RecordCommitOp(group, indexer=self.indexer, index_refresh=True))
        return self.result_item(
            self, identity, group, errors=errors, links_tpl=self.links_item_tpl
        )

    def read(self, identity, id_):
        """Retrieve a user group."""
        group = GroupAggregate.get_record(id_)
        if group is None:
            raise PermissionDeniedError()
        self.require_permission(identity, "read", record=group)
        for component in self.components:
            if hasattr(component, "read"):
                component.read(identity, group=group)
        return self.result_item(self, identity, group, links_tpl=self.links_item_tpl)

    @unit_of_work()
    def update(self, identity, id_, data, raise_errors=True, uow=None):
        """Update an existing group."""
        group = GroupAggregate.get_record(id_)
        if group is None:
            raise PermissionDeniedError()
        self.require_permission(identity, "update", record=group, update_grp=data)

        try:
            data, errors = self.schema.load(
                data or {},
                schema_args={"partial": True},
                context={"identity": identity, "record": group},
                raise_errors=raise_errors,
            )
        except ValidationError as err:
            raise GroupValidationError(err.messages) from err

        try:
            # Update group using API
            group = group.update(data, id_)
        except ValidationError as err:
            raise GroupValidationError(err.messages) from err
        current_app.logger.debug(
            "Group updated: '%s' by user %s", group.name, identity.id
        )

        self.run_components(
            "update",
            identity,
            data=data,
            group=group,
            errors=errors,
            uow=uow,
        )

        uow.register(RecordCommitOp(group, indexer=self.indexer, index_refresh=True))
        return self.result_item(
            self,
            identity,
            group,
            errors=errors,
            links_tpl=self.links_item_tpl,
        )

    @unit_of_work()
    def delete(self, identity, id_, uow=None):
        """Delete a group."""
        group = GroupAggregate.get_record(id_)
        if group is None:
            raise PermissionDeniedError()
        self.require_permission(identity, "delete", record=group)

        current_app.logger.debug(
            "Group deleted: '%s' by user %s", group.name, identity.id
        )

        # Delete group using API
        group.delete()

        self.run_components(
            "delete",
            identity,
            group=group,
            uow=uow,
        )

        uow.register(
            RecordIndexDeleteOp(group, indexer=self.indexer, index_refresh=True)
        )

        return True

    def read_avatar(self, identity, id_):
        """Get a groups's avatar."""
        group = GroupAggregate.get_record(id_)
        if group is None:
            # return 403 even on empty resource due to security implications
            raise PermissionDeniedError()
        self.require_permission(identity, "read", record=group)
        return AvatarResult(group)

    def rebuild_index(self, identity, uow=None):
        """Reindex all user groups managed by this service."""
        roles = db.session.query(Role.id).yield_per(1000)

        self.indexer.bulk_index([r.id for r in roles])

        return True



# -*- coding: utf-8 -*-
#
# Copyright (C) 2022-2026 CERN.
# Copyright (C) 2022-2023 TU Wien.
# Copyright (C) 2024-2026 Graz University of Technology.
#
# Invenio-Users-Resources is free software; you can redistribute it and/or
# modify it under the terms of the MIT License; see LICENSE file for more
# details.

"""Invenio module providing management APIs for users and roles/groups."""

__version__ = "10.4.1"

__all__ = ("__version__",)



# -*- coding: utf-8 -*-
#
# Copyright (C) 2022 TU Wien.
# Copyright (C) 2022 CERN.
# Copyright (C) 2023 Graz University of Technology.
# Copyright (C) 2024-2025 KTH Royal Institute of Technology.
# Copyright (C) 2025 Ubiquity Press.
#
# Invenio-Users-Resources is free software; you can redistribute it and/or
# modify it under the terms of the MIT License; see LICENSE file for more
# details.

"""Permission generators for users and groups."""

from abc import abstractmethod

from flask import current_app
from invenio_access import (
    ActionRoles,
    ActionUsers,
    Permission,
    any_user,
    superuser_access,
)
from invenio_access.models import Role
from invenio_access.permissions import system_process
from invenio_access.utils import get_identity
from invenio_db import db
from invenio_records.dictutils import dict_lookup
from invenio_records_permissions.generators import (
    ConditionalGenerator,
    Generator,
    UserNeed,
)
from invenio_search.engine import dsl
from sqlalchemy import exists


class IfPublic(ConditionalGenerator):
    """Generator for different permissions based on the visibility settings."""

    def __init__(self, field_name, then_, else_, **kwargs):
        """Constructor."""
        super().__init__(then_=then_, else_=else_, **kwargs)
        self._field_name = field_name

    def _condition(self, record=None, **kwargs):
        """Condition to choose generators set."""
        if record is None:
            return False

        visibility = record.preferences.get(self._field_name, "restricted")
        is_public = visibility == "public"

        return is_public

    def query_filter(self, **kwargs):
        """Filters for queries."""
        field = f"preferences.{self._field_name}"
        q_public = dsl.Q("match", **{field: "public"})
        q_restricted = dsl.Q("match", **{field: "restricted"})
        then_query = self._make_query(self.then_, **kwargs)
        else_query = self._make_query(self.else_, **kwargs)

        if then_query and else_query:
            return (q_public & then_query) | (q_restricted & else_query)
        elif then_query:
            return q_public & then_query
        elif else_query:
            return q_public | (q_restricted & else_query)
        else:
            return q_public


class IfPublicEmail(IfPublic):
    """Generator checking the 'email_visibility' setting."""

    def __init__(self, then_, else_):
        """Constructor."""
        super().__init__("email_visibility", then_, else_)


class IfPublicUser(IfPublic):
    """Generator checking the 'visibility' setting."""

    def __init__(self, then_, else_):
        """Constructor."""
        super().__init__("visibility", then_, else_)


class Self(Generator):
    """Requires the users themselves."""

    def needs(self, record=None, **kwargs):
        """Set of Needs granting permission."""
        if record is not None:
            return [UserNeed(record.id)]

        return []

    def query_filter(self, identity=None, **kwargs):
        """Filters for the current identity."""
        if identity is not None:
            for need in identity.provides:
                if need.method == "id":
                    return dsl.Q("term", id=need.value)

        return []


class PreventSelf(Generator):
    """Prevents users from performing actions on themselves."""

    def excludes(self, record=None, actor_id=None, **kwargs):
        """Exclude needs to prevent self-actions."""
        if record is None or actor_id is None:
            return []
        if actor_id == record.id:
            return [UserNeed(record.id)]
        return []


class IfGroupNotManaged(ConditionalGenerator):
    """Generator for managed group access."""

    def __init__(self, then_, else_, **kwargs):
        """Constructor."""
        super().__init__(then_=then_, else_=else_, **kwargs)
        self._field_name = "is_managed"

    def _condition(self, record, **kwargs):
        """Condition to choose generators set."""
        if record is None:
            return False

        is_managed = dict_lookup(record, self._field_name)
        return not is_managed

    def query_filter(self, **kwargs):
        """Filters for queries."""
        q_not_managed = dsl.Q("match", **{self._field_name: False})
        then_query = self._make_query(self.then_, **kwargs)
        else_query = self._make_query(self.else_, **kwargs)
        identity = kwargs.get("identity", None)
        if identity:
            permission = Permission(*self.needs(**kwargs))
            if permission.allows(identity):
                return else_query

        return q_not_managed & then_query


class GroupsEnabled(Generator):
    """Generator to restrict if the groups are not enabled.

    If the groups are not enabled, exclude any user for adding members of the
    param member type.

    A system process is allowed to do anything.
    """

    def __init__(self, *need_groups_enabled_types):
        """Types that need the groups enabled."""
        self.need_groups_enabled_types = need_groups_enabled_types

    def excludes(self, member_types=None, **kwargs):
        """Preventing needs."""
        member_types = member_types or {"group"}
        for m in member_types:
            if (
                m in self.need_groups_enabled_types
                and not current_app.config["USERS_RESOURCES_GROUPS_ENABLED"]
            ):
                return [any_user]
        return []


class DenyAll(Generator):
    """Generator that denies all access by excluding any_user."""

    def excludes(self, **kwargs):
        """Exclude all users."""
        return [any_user]


class ProtectedGroupIdentifiers(Generator):
    """Exclude access to protected groups unless system process."""

    def _is_protected(self, record, **kwargs):
        """Check if the role is a protected."""
        protected = set(
            current_app.config.get("USERS_RESOURCES_PROTECTED_GROUP_NAMES", [])
        )
        if not protected or record is None:
            return False

        # create new role
        name_dict = record.get("name") if isinstance(record, dict) else None
        # update protected role (object form)
        name_obj = getattr(record, "name", None)
        id_obj = getattr(record, "id", None)
        # update role to protected
        update_name = kwargs.get("update_grp", {}).get("name")

        candidates = {str(v) for v in (name_dict, name_obj, id_obj, update_name) if v}
        return bool(protected & candidates)

    def excludes(self, record=None, identity=None, **kwargs):
        """Exclude non-system identities from protected groups."""
        if not self._is_protected(record, **kwargs):
            return []
        if identity and system_process in identity.provides:
            return []
        return [any_user]


class AdministrationAction(Generator):
    """Similar to `AdminnAction` but it safe gards superadmin users and/or roles."""

    def __init__(self, action):
        """Constructor.

        :param action: The action to check permissions against, i.e. `administration-moderation`
        """
        self.action = action

    @abstractmethod
    def _records_to_exclude(self):
        """Get IDs of records to exclude from the query."""

    def needs(self, **kwargs):
        """Enabling Needs."""
        return [self.action]

    def query_filter(self, identity=None, **kwargs):
        """Filter query to exclude protected records if user has permission."""
        if not identity:
            return []

        permission = Permission(self.action)
        if not permission.allows(identity):
            return []

        exclude_ids = self._records_to_exclude()
        if not exclude_ids:
            return dsl.Q("match_all")

        return dsl.Q("match_all") & ~dsl.Q("terms", id=exclude_ids)


class AdministrationUserAction(AdministrationAction):
    """Administration action to hide superadmin users from non-superadmin users."""

    def _records_to_exclude(self):
        """Get IDs of users with superadmin access."""
        # Users via role membership
        users_via_roles = {
            user.id
            for action_role in ActionRoles.query_by_action(superuser_access).all()
            for user in action_role.role.users
        }

        # Users with direct action assignments
        users_via_actions = {
            action_user.user_id
            for action_user in ActionUsers.query_by_action(superuser_access).all()
        }
        # Return the union of both
        return list(users_via_roles | users_via_actions)


class AdministrationGroupAction(AdministrationAction):
    """Administration action to hide superadmin roles from non-superadmin users."""

    def _records_to_exclude(self):
        """Get IDs of roles with superadmin access."""
        return [
            action_role.role_id
            for action_role in ActionRoles.query_by_action(superuser_access).all()
        ]


class IfSuperAdmin(ConditionalGenerator):
    """Generator that conditionally grants access based on superadmin status."""

    def _is_user_superadmin(self, identity):
        """Check if the identity has superadmin access."""
        if not identity:
            return False
        return Permission(superuser_access).allows(identity)

    def _is_role_superadmin(self, record):
        """Check if a role record has superadmin access."""
        return db.session.query(
            exists(
                ActionRoles.query_by_action(superuser_access)
                .filter_by(role_id=record.id)
                .statement
            )
        ).scalar()

    def _is_record_superadmin(self, record):
        """Check if a record represents a superadmin role or user."""
        if isinstance(record.model.model_obj, Role):
            return self._is_role_superadmin(record)

        record_identity = get_identity(record.model.model_obj)
        return self._is_user_superadmin(record_identity)

    def _condition(self, record=None, identity=None, **kwargs):
        """Check if user or record has superadmin access."""
        # Check current user's identity first
        if identity and self._is_user_superadmin(identity):
            return True

        # Check the record if provided
        return record is not None and self._is_record_superadmin(record)

    def query_filter(self, identity=None, **kwargs):
        """Generate query filter based on superadmin status."""
        generator = self.then_ if self._is_user_superadmin(identity) else self.else_
        return self._make_query(generator, identity=identity, **kwargs)



# -*- coding: utf-8 -*-
#
# Copyright (C) 2022 TU Wien.
# Copyright (C) 2022 CERN.
# Copyright (C) 2025 KTH Royal Institute of Technology.
#
# Invenio-Users-Resources is free software; you can redistribute it and/or
# modify it under the terms of the MIT License; see LICENSE file for more
# details.

"""User roles/groups resource config."""

import marshmallow as ma
from flask_resources import HTTPJSONException
from invenio_records_resources.errors import validation_error_to_list_errors
from invenio_records_resources.resources import (
    RecordResource,
    RecordResourceConfig,
    SearchRequestArgsSchema,
)
from invenio_records_resources.resources.errors import PermissionDeniedError
from marshmallow import ValidationError

from .errors import GroupValidationError


#
# Request args
#
class GroupSearchRequestArgsSchema(SearchRequestArgsSchema):
    """Add parameter to parse tags."""

    title = ma.fields.String()


def handle_group_validation_error(err):
    """Handle groups errors."""
    marshmallow_error = ValidationError(err.errors)
    response = HTTPJSONException(
        code=400,
        description=err.description,
        errors=validation_error_to_list_errors(marshmallow_error),
    )
    return response.get_response()


def handle_group_permission_error(err):
    """Handle permission errors."""
    response = HTTPJSONException(code=403, description=err.description)
    return response.get_response()


#
# Resource config
#
class GroupsResourceConfig(RecordResourceConfig):
    """User groups resource configuration."""

    blueprint_name = "groups"
    url_prefix = "/groups"
    routes = {
        "list": "",
        "item": "/<id>",
        "item-avatar": "/<id>/avatar.svg",
    }

    request_view_args = {
        "id": ma.fields.Str(),
    }

    request_search_args = GroupSearchRequestArgsSchema

    error_handlers = {
        **RecordResource.error_handlers,
        GroupValidationError: handle_group_validation_error,
        PermissionDeniedError: handle_group_permission_error,
    }

    response_handlers = {
        "application/vnd.inveniordm.v1+json": RecordResourceConfig.response_handlers[
            "application/json"
        ],
        **RecordResourceConfig.response_handlers,
    }



# -*- coding: utf-8 -*-
#
# Copyright (C) 2022 TU Wien.
# Copyright (C) 2022-2026 CERN.
# Copyright (C) 2024 KTH Royal Institute of Technology.
# Copyright (C) 2025 Northwestern University.
#
# Invenio-Users-Resources is free software; you can redistribute it and/or
# modify it under the terms of the MIT License; see LICENSE file for more
# details.

"""Users service configuration."""

from invenio_accounts.utils import DomainStatus
from invenio_records_resources.services import (
    EndpointLink,
    RecordServiceConfig,
    pagination_endpoint_links,
)
from invenio_records_resources.services.base.config import (
    ConfiguratorMixin,
    FromConfig,
    FromConfigSearchOptions,
    SearchOptionsMixin,
)
from invenio_records_resources.services.records.config import SearchOptions
from invenio_records_resources.services.records.params import (
    FacetsParam,
    PaginationParam,
    QueryStrParam,
    SortParam,
)
from invenio_records_resources.services.records.queryparser import (
    CompositeSuggestQueryParser,
    FieldValueMapper,
    QueryParser,
    SearchFieldTransformer,
)
from luqum.tree import Word

from ...records.api import UserAggregate
from ..common import EndpointLinkWithId, vars_func_set_querystring
from ..params import FixedPagination
from ..permissions import UsersPermissionPolicy
from ..schemas import UserSchema
from .results import UserItem, UserList
from .search_params import ModerationFilterParam


def can_manage(obj, ctx):
    """Check if user can manage."""
    from invenio_users_resources.proxies import current_users_service

    return current_users_service.check_permission(ctx["identity"], "manage")


def word_domain_status(node):
    """Quote DOIs."""
    val = node.value
    if val in ["verified", "blocked", "moderated", "new"]:
        val = DomainStatus[node.value].value
    return Word(f"{val}")


class UserSearchOptions(SearchOptions, SearchOptionsMixin):
    """Search options."""

    pagination_options = {
        "default_results_per_page": 10,
        "default_max_results": 10,
    }
    # ATTENTION: Risk of leaking account information!!!
    # The user search needs to be highly restricted to avoid leaking
    # account information, hence do not edit here unless you are
    # absolutely sure what you're doing.
    suggest_parser_cls = CompositeSuggestQueryParser.factory(
        tree_transformer_cls=SearchFieldTransformer,
        fields=[
            "username.keyword^2",
            "username^2",
            "email.keyword^2",
            "email^2",
            "profile.full_name^10",
            "profile.affiliations",
        ],
        # Only public emails because hidden emails are stored in email_hidden field.
        allow_list=["username", "email"],
        mapping={
            "affiliation": "profile.affiliations",
            "affiliations": "profile.affiliations",
            "full_name": "profile.full_name",
            "fullname": "profile.full_name",
            "name": "profile.full_name",
        },
    )

    params_interpreters_cls = [
        QueryStrParam,
        SortParam,
        FixedPagination,
        FacetsParam,
    ]


class AdminUserSearchOptions(UserSearchOptions):
    """Admin Search options."""

    pagination_options = {
        "default_results_per_page": 20,
        "default_max_results": 10_000,
    }

    query_parser_cls = QueryParser.factory(
        tree_transformer_cls=SearchFieldTransformer,
        fields=[
            "username^3",
            "email_hidden^3",
            "domain^2",
            "profile.full_name^3",
            "profile.affiliations",
        ],
        allow_list=[
            "id",
            "username",
            "domain",
            "email_hidden",
            "profile.full_name",
            "profile.affiliations",
            "created",
            "updated",
            "confirmed",
            "confirmed_at",
            "blocked_at",
            "verified_at",
            "preferences.visibility",
            "preferences.email_visibility",
            "visibility",
            "status",
            "current_login_at",
            "identities.github",
            "identities.orcid",
            "identities.openaire",
            "domaininfo.status",
            "domaininfo.flagged",
            "domaininfo.tld",
            "domaininfo.category",
        ],
        mapping={
            "affiliation": "profile.affiliations",
            "affiliations": "profile.affiliations",
            "full_name": "profile.full_name",
            "fullname": "profile.full_name",
            "name": "profile.full_name",
            "email": "email_hidden",
            "visibility": "preferences.visibility",
            "email_visibility": "preferences.email_visibility",
            "github": "identities.github",
            "orcid": "identities.orcid",
            "openaire": "identities.openaire",
            "domain.status": FieldValueMapper(
                "domaininfo.status", word=word_domain_status
            ),
            "domain.tld": "domaininfo.tld",
            "domain.category": "domaininfo.category",
            "domain.flagged": "domaininfo.flagged",
        },
    )

    params_interpreters_cls = [
        QueryStrParam,
        SortParam,
        PaginationParam,
        FacetsParam,
        ModerationFilterParam.factory(param="is_blocked", field="blocked_at"),
        ModerationFilterParam.factory(param="is_verified", field="verified_at"),
        ModerationFilterParam.factory(param="is_active", field="active"),
    ]


class UsersServiceConfig(RecordServiceConfig, ConfiguratorMixin):
    """Requests service configuration."""

    # common configuration
    permission_policy_cls = UsersPermissionPolicy
    result_item_cls = UserItem
    result_list_cls = UserList
    # We're not allowing override of options to prevent risk of
    # leaking account information.
    search = UserSearchOptions

    # For admin user
    search_all = FromConfigSearchOptions(
        "USERS_RESOURCES_SEARCH",
        "USERS_RESOURCES_SORT_OPTIONS",
        "USERS_RESOURCES_SEARCH_FACETS",
        search_option_cls=AdminUserSearchOptions,
    )
    # search = UserSearchOptions
    # specific configuration
    service_id = "users"
    record_cls = UserAggregate
    schema = FromConfig("USERS_RESOURCES_SERVICE_SCHEMA", UserSchema)
    indexer_queue_name = "users"
    index_dumper = None

    # links configuration
    links_item = {
        "self": EndpointLinkWithId("users.read"),
        "avatar": EndpointLinkWithId("users.avatar"),
        "records_html": EndpointLink(
            "invenio_search_ui.search",
            vars=vars_func_set_querystring(
                lambda obj, vars: {"q": f"parent.access.owned_by.user:{obj.id}"}
            ),
        ),
        "admin_records_html": EndpointLink(
            "administration.records",
            vars=vars_func_set_querystring(
                lambda obj, vars: {
                    "q": f"parent.access.owned_by.user:{obj.id}",
                    "f": "allversions",
                }
            ),
            when=can_manage,
        ),
        "admin_drafts_html": EndpointLink(
            "administration.drafts",
            vars=vars_func_set_querystring(
                lambda obj, vars: {
                    "q": f"parent.access.owned_by.user:{obj.id}",
                    "f": "allversions",
                }
            ),
            when=can_manage,
        ),
        "admin_moderation_html": EndpointLink(
            "administration.moderation",
            vars=vars_func_set_querystring(
                lambda obj, vars: {"q": f"topic.user:{obj.id}"}
            ),
            when=can_manage,
        ),
        # TODO missing moderation actions based on permissions
    }

    links_search = pagination_endpoint_links("users.search")

    components = [
        # order of components are important!
    ]



# -*- coding: utf-8 -*-
#
# Copyright (C) 2022 TU Wien.
#
# Invenio-Users-Resources is free software; you can redistribute it and/or
# modify it under the terms of the MIT License; see LICENSE file for more
# details.

"""Resources for user roles/groups."""

from .config import DomainsResourceConfig
from .resource import DomainsResource

__all__ = (
    "DomainsResource",
    "DomainsResourceConfig",
)



# -*- coding: utf-8 -*-
#
# Copyright (C) 2025 CERN.
# Copyright (C) 2025 KTH Royal Institute of Technology.
#
# Invenio-Users-Resources is free software; you can redistribute it and/or
# modify it under the terms of the MIT License; see LICENSE file for more
# details.

"""Groups search facets definitions."""

from invenio_i18n import lazy_gettext as _
from invenio_records_resources.services.records.facets import TermsFacet

is_managed = TermsFacet(
    field="is_managed",
    label=_("Management state"),
    value_labels={
        "false": _("Unmanaged"),
        "true": _("Managed"),
    },
)
